// Package loggingapi provides primitives to interact with the openapi HTTP API.
//
// Code generated by github.com/deepmap/oapi-codegen version v1.10.1 DO NOT EDIT.
package loggingapi

import (
	externalRef0 "oransc.org/nonrtric/capifcore/internal/common29122"
	externalRef1 "oransc.org/nonrtric/capifcore/internal/common29571"
	externalRef2 "oransc.org/nonrtric/capifcore/internal/publishserviceapi"
)

// Unsigned integer identifying a period of time in units of milliseconds.
type DurationMs int

// Represents a set of Service API invocation logs to be stored in a CAPIF core function.
type InvocationLog struct {
	// Identity information of the API exposing function requesting logging of service API invocations
	AefId string `json:"aefId"`

	// Identity of the API invoker which invoked the service API
	ApiInvokerId string `json:"apiInvokerId"`

	// Service API invocation log
	Logs []Log `json:"logs"`

	// A string used to indicate the features supported by an API that is used as defined in clause  6.6 in 3GPP TS 29.500. The string shall contain a bitmask indicating supported features in  hexadecimal representation Each character in the string shall take a value of "0" to "9",  "a" to "f" or "A" to "F" and shall represent the support of 4 features as described in  table 5.2.2-3. The most significant character representing the highest-numbered features shall  appear first in the string, and the character representing features 1 to 4 shall appear last  in the string. The list of features and their numbering (starting with 1) are defined  separately for each API. If the string contains a lower number of characters than there are  defined features for an API, all features that would be represented by characters that are not  present in the string are not supported.
	SupportedFeatures *externalRef1.SupportedFeatures `json:"supportedFeatures,omitempty"`
}

// Represents an individual service API invocation log entry.
type Log struct {
	// String identifying the API invoked.
	ApiId string `json:"apiId"`

	// Name of the API which was invoked, it is set as {apiName} part of the URI structure as defined in clause 5.2.4 of 3GPP TS 29.122.
	ApiName string `json:"apiName"`

	// Version of the API which was invoked
	ApiVersion string `json:"apiVersion"`

	// Represents the description of an API's interface.
	DestInterface *externalRef2.InterfaceDescription `json:"destInterface,omitempty"`

	// It includes the node identifier (as defined in IETF RFC 7239 of all forwarding entities between the API invoker and the AEF, concatenated with comma and space, e.g. 192.0.2.43:80, unknown:_OBFport, 203.0.113.60
	FwdInterface *string `json:"fwdInterface,omitempty"`

	// List of input parameters. Can be any value - string, number, boolean, array or object.
	InputParameters *interface{} `json:"inputParameters,omitempty"`

	// Unsigned integer identifying a period of time in units of milliseconds.
	InvocationLatency *DurationMs `json:"invocationLatency,omitempty"`

	// string with format "date-time" as defined in OpenAPI.
	InvocationTime *externalRef0.DateTime `json:"invocationTime,omitempty"`

	// Possible values are:
	// - GET: HTTP GET method
	// - POST: HTTP POST method
	// - PUT: HTTP PUT method
	// - PATCH: HTTP PATCH method
	// - DELETE: HTTP DELETE method
	Operation *externalRef2.Operation `json:"operation,omitempty"`

	// List of output parameters. Can be any value - string, number, boolean, array or object.
	OutputParameters *interface{} `json:"outputParameters,omitempty"`

	// Possible values are:
	// - HTTP_1_1: HTTP version 1.1
	// - HTTP_2: HTTP version 2
	Protocol externalRef2.Protocol `json:"protocol"`

	// Name of the specific resource invoked
	ResourceName string `json:"resourceName"`

	// For HTTP protocol, it contains HTTP status code of the invocation
	Result string `json:"result"`

	// Represents the description of an API's interface.
	SrcInterface *externalRef2.InterfaceDescription `json:"srcInterface,omitempty"`

	// string providing an URI formatted according to IETF RFC 3986.
	Uri *externalRef0.Uri `json:"uri,omitempty"`
}

// PostAefIdLogsJSONBody defines parameters for PostAefIdLogs.
type PostAefIdLogsJSONBody InvocationLog

// PostAefIdLogsJSONRequestBody defines body for PostAefIdLogs for application/json ContentType.
type PostAefIdLogsJSONRequestBody PostAefIdLogsJSONBody
