// Package securityapi provides primitives to interact with the openapi HTTP API.
//
// Code generated by github.com/deepmap/oapi-codegen version v1.10.1 DO NOT EDIT.
package securityapi

import (
	externalRef0 "oransc.org/nonrtric/capifcore/internal/common29122"
	externalRef1 "oransc.org/nonrtric/capifcore/internal/common29571"
)

// Defines values for AccessTokenErrError.
const (
	AccessTokenErrErrorInvalidClient AccessTokenErrError = "invalid_client"

	AccessTokenErrErrorInvalidGrant AccessTokenErrError = "invalid_grant"

	AccessTokenErrErrorInvalidRequest AccessTokenErrError = "invalid_request"

	AccessTokenErrErrorInvalidScope AccessTokenErrError = "invalid_scope"

	AccessTokenErrErrorUnauthorizedClient AccessTokenErrError = "unauthorized_client"

	AccessTokenErrErrorUnsupportedGrantType AccessTokenErrError = "unsupported_grant_type"
)

// Defines values for AccessTokenReqGrantType.
const (
	AccessTokenReqGrantTypeClientCredentials AccessTokenReqGrantType = "client_credentials"
)

// Defines values for AccessTokenRspTokenType.
const (
	AccessTokenRspTokenTypeBearer AccessTokenRspTokenType = "Bearer"
)

// Defines values for Cause.
const (
	CauseOVERLIMITUSAGE Cause = "OVERLIMIT_USAGE"

	CauseUNEXPECTEDREASON Cause = "UNEXPECTED_REASON"
)

// Represents an error in the access token request.
type AccessTokenErr struct {
	Error            AccessTokenErrError `json:"error"`
	ErrorDescription *string             `json:"error_description,omitempty"`
	ErrorUri         *string             `json:"error_uri,omitempty"`
}

// AccessTokenErrError defines model for AccessTokenErr.Error.
type AccessTokenErrError string

// Represents the access token request information.
type AccessTokenReq struct {
	ClientId     string                  `json:"client_id"`
	ClientSecret *string                 `json:"client_secret,omitempty"`
	GrantType    AccessTokenReqGrantType `json:"grant_type"`
	Scope        *string                 `json:"scope,omitempty"`
}

// AccessTokenReqGrantType defines model for AccessTokenReq.GrantType.
type AccessTokenReqGrantType string

// Represents the access token response information.
type AccessTokenRsp struct {
	// JWS Compact Serialized representation of JWS signed JSON object (AccessTokenClaims)
	AccessToken string `json:"access_token"`

	// Unsigned integer identifying a period of time in units of seconds.
	ExpiresIn externalRef0.DurationSec `json:"expires_in"`
	Scope     *string                  `json:"scope,omitempty"`
	TokenType AccessTokenRspTokenType  `json:"token_type"`
}

// AccessTokenRspTokenType defines model for AccessTokenRsp.TokenType.
type AccessTokenRspTokenType string

// Possible values are:
// - OVERLIMIT_USAGE: The revocation of the authorization of the API invoker is due to the overlimit usage of the service API
// - UNEXPECTED_REASON: The revocation of the authorization of the API invoker is due to unexpected reason.
type Cause string

// Represents the interface details and the security method.
type SecurityInformation interface{}

// Represents revoked authorization notification details.
type SecurityNotification struct {
	// String identifying the AEF.
	AefId *string `json:"aefId,omitempty"`

	// Identifier of the service API
	ApiIds []string `json:"apiIds"`

	// String identifying the API invoker assigned by the CAPIF core function.
	ApiInvokerId string `json:"apiInvokerId"`

	// Possible values are:
	// - OVERLIMIT_USAGE: The revocation of the authorization of the API invoker is due to the overlimit usage of the service API
	// - UNEXPECTED_REASON: The revocation of the authorization of the API invoker is due to unexpected reason.
	Cause Cause `json:"cause"`
}

// Represents the details of the security method for each service API interface. When included by the API invoker, it indicates the preferred method of security. When included by the CAPIF core function, it indicates the security method to be used for the service API interface.
type ServiceSecurity struct {
	// string providing an URI formatted according to IETF RFC 3986.
	NotificationDestination externalRef0.Uri `json:"notificationDestination"`

	// Set to true by API invoker to request the CAPIF core function to send a test notification as defined in in clause 7.6. Set to false or omitted otherwise.
	RequestTestNotification *bool                 `json:"requestTestNotification,omitempty"`
	SecurityInfo            []SecurityInformation `json:"securityInfo"`

	// A string used to indicate the features supported by an API that is used as defined in clause  6.6 in 3GPP TS 29.500. The string shall contain a bitmask indicating supported features in  hexadecimal representation Each character in the string shall take a value of "0" to "9",  "a" to "f" or "A" to "F" and shall represent the support of 4 features as described in  table 5.2.2-3. The most significant character representing the highest-numbered features shall  appear first in the string, and the character representing features 1 to 4 shall appear last  in the string. The list of features and their numbering (starting with 1) are defined  separately for each API. If the string contains a lower number of characters than there are  defined features for an API, all features that would be represented by characters that are not  present in the string are not supported.
	SupportedFeatures *externalRef1.SupportedFeatures `json:"supportedFeatures,omitempty"`

	// Represents the configuration information for the delivery of notifications over Websockets.
	WebsockNotifConfig *externalRef0.WebsockNotifConfig `json:"websockNotifConfig,omitempty"`
}

// GetTrustedInvokersApiInvokerIdParams defines parameters for GetTrustedInvokersApiInvokerId.
type GetTrustedInvokersApiInvokerIdParams struct {
	// When set to 'true', it indicates the CAPIF core function to send the authentication information of the API invoker. Set to false or omitted otherwise.
	AuthenticationInfo *bool `json:"authenticationInfo,omitempty"`

	// When set to 'true', it indicates the CAPIF core function to send the authorization information of the API invoker. Set to false or omitted otherwise.
	AuthorizationInfo *bool `json:"authorizationInfo,omitempty"`
}

// PutTrustedInvokersApiInvokerIdJSONBody defines parameters for PutTrustedInvokersApiInvokerId.
type PutTrustedInvokersApiInvokerIdJSONBody ServiceSecurity

// PostTrustedInvokersApiInvokerIdDeleteJSONBody defines parameters for PostTrustedInvokersApiInvokerIdDelete.
type PostTrustedInvokersApiInvokerIdDeleteJSONBody SecurityNotification

// PostTrustedInvokersApiInvokerIdUpdateJSONBody defines parameters for PostTrustedInvokersApiInvokerIdUpdate.
type PostTrustedInvokersApiInvokerIdUpdateJSONBody ServiceSecurity

// PutTrustedInvokersApiInvokerIdJSONRequestBody defines body for PutTrustedInvokersApiInvokerId for application/json ContentType.
type PutTrustedInvokersApiInvokerIdJSONRequestBody PutTrustedInvokersApiInvokerIdJSONBody

// PostTrustedInvokersApiInvokerIdDeleteJSONRequestBody defines body for PostTrustedInvokersApiInvokerIdDelete for application/json ContentType.
type PostTrustedInvokersApiInvokerIdDeleteJSONRequestBody PostTrustedInvokersApiInvokerIdDeleteJSONBody

// PostTrustedInvokersApiInvokerIdUpdateJSONRequestBody defines body for PostTrustedInvokersApiInvokerIdUpdate for application/json ContentType.
type PostTrustedInvokersApiInvokerIdUpdateJSONRequestBody PostTrustedInvokersApiInvokerIdUpdateJSONBody
